@@ -595,6 +595,40 @@ _wnck_get_utf8_list (Window   xwindow,
   return retval;
 }
 
+void
+_wnck_set_utf8_list (Window   xwindow,
+                     Atom     atom,
+                     char   **list)
+{
+  Atom utf8_string;
+  GString *flattened;
+  int i;
+  
+  utf8_string = _wnck_atom_get ("UTF8_STRING");  
+
+  /* flatten to nul-separated list */
+  flattened = g_string_new ("");
+  i = 0;
+  while (list[i] != NULL)
+    {
+      g_string_append_len (flattened, list[i],
+                           strlen (list[i]) + 1);
+      ++i;
+    }
+
+  _wnck_error_trap_push ();
+  
+  XChangeProperty (gdk_display,
+		   xwindow,
+                   atom,
+		   utf8_string, 8, PropModeReplace,
+		   flattened->str, flattened->len);
+  
+  _wnck_error_trap_pop ();
+
+  g_string_free (flattened, TRUE);
+}
+
 void
 _wnck_error_trap_push (void)
 {
@@ -2106,15 +2140,17 @@ _wnck_get_fallback_icons (GdkPixbuf **iconp,
                           int         ideal_mini_width,
                           int         ideal_mini_height)
 {
-  *iconp = default_icon_at_size (ideal_width > 0 ? ideal_width :
-                                 DEFAULT_ICON_WIDTH,
-                                 ideal_height > 0 ? ideal_height :
-                                 DEFAULT_ICON_HEIGHT);
+  if (iconp)
+    *iconp = default_icon_at_size (ideal_width > 0 ? ideal_width :
+                                   DEFAULT_ICON_WIDTH,
+                                   ideal_height > 0 ? ideal_height :
+                                   DEFAULT_ICON_HEIGHT);
 
-  *mini_iconp = default_icon_at_size (ideal_mini_width > 0 ? ideal_mini_width :
-                                      DEFAULT_MINI_ICON_WIDTH,
-                                      ideal_mini_height > 0 ? ideal_mini_height :
-                                      DEFAULT_MINI_ICON_HEIGHT);
+  if (mini_iconp)
+    *mini_iconp = default_icon_at_size (ideal_mini_width > 0 ? ideal_mini_width :
+                                        DEFAULT_MINI_ICON_WIDTH,
+                                        ideal_mini_height > 0 ? ideal_mini_height :
+                                        DEFAULT_MINI_ICON_HEIGHT);
 }
 
 
@@ -2254,7 +2290,7 @@ _wnck_set_desktop_layout (Screen *xscreen,
                    RootWindowOfScreen (xscreen),
 		   _wnck_atom_get ("_NET_DESKTOP_LAYOUT"),
 		   XA_CARDINAL, 32, PropModeReplace,
-		   (guchar *)&data, sizeof (data));
+		   (guchar *)&data, sizeof (data) / 4);
 
   _wnck_error_trap_pop ();
 }
